@@ -1,3 +1,17 @@
+# Copyright 2021 cstsunfu. All rights reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 """schedulers"""
 import importlib
 import os
@@ -12,21 +26,19 @@ scheduler_register = Register("Schedule register.")
 
 
 class BaseScheduler(object):
-    """docstring for BaseSchedule"""
+    """interface for Schedule"""
 
-    def get_scheduler(self):
-        """TODO: Docstring for get_scheduler.
-        :returns: TODO
+    def get_scheduler(self)->LambdaLR:
+        """return the initialized scheduler
+
+        Returns: 
+            Schedule
 
         """
         raise NotImplementedError
 
     def __call__(self):
-        """TODO: Docstring for __call__.
-
-        :arg1: TODO
-        :returns: TODO
-
+        """the same as self.get_scheduler()
         """
         return self.get_scheduler()
 
