@@ -90,7 +90,8 @@ class IPostProcessor(metaclass=abc.ABCMeta):
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
@@ -113,7 +114,9 @@ class IPostProcessor(metaclass=abc.ABCMeta):
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> 
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
@@ -136,7 +139,8 @@ class IPostProcessor(metaclass=abc.ABCMeta):
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
@@ -168,7 +172,8 @@ class IPostProcessor(metaclass=abc.ABCMeta):
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
