@@ -39,6 +39,9 @@ class SeqLabPostProcessorConfig(IPostProcessorConfig):
         >>>         "meta": "*@*",
         >>>         "use_crf": false, //use or not use crf
         >>>         "word_ready": false, //already gather the subword first token as the word rep or not
+        >>>         "ignore_position": true, // calc the metrics, whether ignore the ground_truth and predict position info.( if set to true, only focus on the entity content not position.)
+        >>>         "ignore_char": " ", // if the entity begin or end with this char, will ignore these char
+        >>>         //"ignore_char": " ()[]-.,:", // if the entity begin or end with this char, will ignore these char
         >>>         "meta_data": {
         >>>             "label_vocab": 'label_vocab',
         >>>             "tokenizer": "tokenizer",
@@ -78,6 +81,8 @@ class SeqLabPostProcessorConfig(IPostProcessorConfig):
         self.word_ready = self.config['word_ready']
         self.aggregation_strategy = self.config['aggregation_strategy']
         self.ignore_labels = set(self.config['ignore_labels'])
+        self.ignore_char = set(self.config['ignore_char'])
+        self.ignore_position = set(self.config['ignore_position'])
 
         self.sentence = self.origin_input_map['sentence']
         self.offsets = self.origin_input_map['offsets']
@@ -167,7 +172,8 @@ class SeqLabPostProcessor(IPostProcessor):
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
@@ -196,7 +202,8 @@ class SeqLabPostProcessor(IPostProcessor):
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
@@ -237,7 +244,24 @@ class SeqLabPostProcessor(IPostProcessor):
                 label = item['labels'][0]
                 if label not in info:
                     info[label] = []
-                info[label].append(text[item['start']: item['end']].strip())
+                start_position, end_position = item['start'], item['end']
+                while start_position < end_position:
+                    if text[start_position] in self.config.ignore_char:
+                        start_position += 1
+                    else:
+                        break
+                while start_position < end_position:
+                    if text[end_position] in self.config.ignore_char:
+                        end_position -= 1
+                    else:
+                        break
+                if start_position == end_position: # if the entity after remove ignore char be null, we set it to origin
+                    start_position, end_position = item['start'], item['end']
+                    
+                if self.config.ignore_position:
+                    info[label].append(text[item['start']: item['end']].strip())
+                else:
+                    info[label].append((start_position, end_position))
             return info
 
         all_predicts = []
@@ -262,7 +286,8 @@ class SeqLabPostProcessor(IPostProcessor):
             stage: train/test/etc.
             list_batch_outputs: a list of outputs
             origin_data: the origin pd.DataFrame data, there are some data not be able to convert to tensor
-            rt_config: current status
+            rt_config:
+                >>> current status
                 >>> {
                 >>>     "current_step": self.global_step,
                 >>>     "current_epoch": self.current_epoch,
@@ -278,7 +303,7 @@ class SeqLabPostProcessor(IPostProcessor):
         if self.config.start_save_epoch == -1 or self.config.start_save_step == -1:
             self.config.start_save_step = rt_config.get('total_steps', 0) - 1
             self.config.start_save_epoch = rt_config.get('total_epochs', 0) - 1
-        if rt_config['current_step']>=self.config.start_save_step or rt_config['current_epoch']>=self.config.start_save_epoch:
+        if not save_condition and (rt_config['current_step']>=self.config.start_save_step or rt_config['current_epoch']>=self.config.start_save_epoch):
             save_condition = True
         if save_condition:
             save_path = os.path.join(self.config.save_root_path, self.config.save_path.get(stage, ''))
@@ -289,7 +314,7 @@ class SeqLabPostProcessor(IPostProcessor):
             else:
                 save_file = os.path.join(save_path, 'predict.json')
             logger.info(f"Save the {stage} predict data at {save_file}")
-            json.dump(predicts, open(save_file, 'w'), indent=4)
+            json.dump(predicts, open(save_file, 'w'), indent=4, ensure_ascii=False)
 
     def calc_score(self, predict_list: List, ground_truth_list: List):
         """use predict_list and ground_truth_list to calc scores
@@ -642,7 +667,7 @@ class SeqLabPostProcessor(IPostProcessor):
         """Group together the adjacent tokens with the same entity predicted.
 
         Args:
-            entities (:obj:`dict`): The entities predicted by the pipeline.
+            entities: The entities predicted by the pipeline.
         """
         # Get the first entity in the entity group
         entity = entities[0]["entity"].split("-")[-1]
@@ -675,7 +700,7 @@ class SeqLabPostProcessor(IPostProcessor):
         """Find and group together the adjacent tokens with the same entity predicted.
 
         Args:
-            entities (:obj:`dict`): The entities predicted by the pipeline.
+            entities: The entities predicted by the pipeline.
         """
 
         entity_groups = []
@@ -710,8 +735,9 @@ class SeqLabPostProcessor(IPostProcessor):
     def aggregate_words(self, entities: List[dict], aggregation_strategy: AggregationStrategy) -> List[dict]:
         """Override tokens from a given word that disagree to force agreement on word boundaries.
 
-        Example: micro|soft| com|pany| B-ENT I-NAME I-ENT I-ENT will be rewritten with first strategy as microsoft|
-        company| B-ENT I-ENT
+        Example: 
+            micro|soft| com|pany| B-ENT I-NAME I-ENT I-ENT will be rewritten with first strategy as microsoft|
+            company| B-ENT I-ENT
         """
         if aggregation_strategy in {
             AggregationStrategy.NONE,
