@@ -1,3 +1,17 @@
+# Copyright 2021 cstsunfu. All rights reserved.
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
 """processors"""
 
 import importlib
@@ -12,10 +26,17 @@ class IProcessor(metaclass=abc.ABCMeta):
 
     @abc.abstractmethod
     def process(self, data: Dict)->Dict:
-        """TODO: Docstring for process.
+        """Process entry
 
-        :arg1: TODO
-        :returns: TODO
+        Args:
+            data: 
+            >>> {
+            >>>     "data": {"train": ...},
+            >>>     "tokenizer": ..
+            >>> }
+
+        Returns: 
+            processed data
 
         """
         raise NotImplementedError
