@@ -218,7 +218,7 @@ class BaseConfigParser(object):
         return {}
 
     @staticmethod
-    def config_link_para(link: Dict[str, Union[str, List[str]]]={}, config: Dict={}):
+    def config_link_para(link: Dict[str, Union[str, List[str]]]=None, config: Dict=None):
         """inplace link the config[to] = config[source]
 
         Args:
@@ -229,6 +229,10 @@ class BaseConfigParser(object):
             None
 
         """
+        if not link:
+            link = {}
+        if not config:
+            config = {}
         def make_link(source: str, to: str):
             """copy the 'source' config to 'to'
             """
@@ -270,7 +274,7 @@ class BaseConfigParser(object):
                 make_link(source, to)
 
     @classmethod
-    def collect_link(cls, config, trace=[], all_level_links={}, level=0):
+    def collect_link(cls, config, trace: List=None, all_level_links: Dict=None, level=0):
         """collect move all links in config to top
 
         only do in the top level of config, collect all level links and return the links with level
@@ -297,6 +301,11 @@ class BaseConfigParser(object):
             >>> }
 
         """
+        if not trace:
+            trace = []
+        if not all_level_links:
+            all_level_links = {}
+            
         if level not in all_level_links:
             all_level_links[level] = {}
         trace_str = ".".join(trace)
@@ -397,7 +406,7 @@ class BaseConfigParser(object):
             logger.warning(f"The Configures is Repeated, Please Check The Configures Carefully.")
             for i, config in enumerate(return_list):
                 logger.info(f"The {i}th Configure is:")
-                logger.info(json.dumps(config, indent=2))
+                logger.info(json.dumps(config, indent=2, ensure_ascii=False))
             raise ValueError('REPEAT CONFIG')
         return return_list
 
@@ -476,7 +485,8 @@ class BaseConfigParser(object):
         Args:
             list_of_list_of_dict: [[config_a1, config_a2], [config_b1, config_b2]]
 
-        Returns: [[config_a1, config_b1], [config_a1, config_b2], [config_a2, config_b1], [config_a2, config_b2]]
+        Returns: 
+            [[config_a1, config_b1], [config_a1, config_b2], [config_a2, config_b1], [config_a2, config_b2]]
 
         """
         if len(list_of_list_of_dict) <= 1:
@@ -497,9 +507,11 @@ class BaseConfigParser(object):
         Args:
             configs: TODO
 
-        Returns: None
+        Returns: 
+            None
 
-        Raises:  ValueError
+        Raises:
+            ValueError
 
         """
         def _check(config):
@@ -509,7 +521,7 @@ class BaseConfigParser(object):
                 if isinstance(config[key], dict):
                     _check(config[key])
                 if config[key] == '*@*':
-                    raise ValueError(f'In Config: \n {json.dumps(config, indent=4)}\n The must be provided key "{key}" marked with "*@*" is not provided.')
+                    raise ValueError(f'In Config: \n {json.dumps(config, indent=4, ensure_ascii=False)}\n The must be provided key "{key}" marked with "*@*" is not provided.')
 
         if isinstance(configs, list):
             for config in configs:
@@ -518,15 +530,18 @@ class BaseConfigParser(object):
             _check(configs)
 
     @staticmethod
-    def get_named_list_cartesian_prod(dict_of_list: Dict[str, List]={}) -> List[Dict]:
+    def get_named_list_cartesian_prod(dict_of_list: Dict[str, List]=None) -> List[Dict]:
         """get catesian prod from named lists
 
         Args:
             dict_of_list: {'name1': [1,2,3], 'name2': [1,2,3]}
 
-        Returns: [{'name1': 1, 'name2': 1}, {'name1': 1, 'name2': 2}, {'name1': 1, 'name2': 3}, ...]
+        Returns: 
+            [{'name1': 1, 'name2': 1}, {'name1': 1, 'name2': 2}, {'name1': 1, 'name2': 3}, ...]
 
         """
+        if not dict_of_list:
+            dict_of_list = {}
         if len(dict_of_list) == 0:
             return []
         dict_of_list = copy.deepcopy(dict_of_list)
@@ -554,11 +569,12 @@ class BaseConfigParser(object):
         Args:
             list_of_dict: a list of dict
 
-        Returns: has repeat or not
+        Returns:
+            has repeat or not
 
         """
         # using json.dumps + sort_keys to guarantee the same dict to the same string represatation
-        list_of_str = [json.dumps(dic, sort_keys=True) for dic in list_of_dict]
+        list_of_str = [json.dumps(dic, sort_keys=True, ensure_ascii=False) for dic in list_of_dict]
         if len(list_of_dict) == len(set(list_of_str)):
             return False
         else:
@@ -584,7 +600,8 @@ class ConfigConfigParser(BaseConfigParser):
         Args:
             parser_link: whether parser the links
 
-        Returns: all valided configs
+        Returns:
+            all valided configs
 
         """
         config_list = self.flat_search(self.search, self.modules)
@@ -615,7 +632,8 @@ class LinkConfigParser(object):
         Args:
             parser_link: must be false
 
-        Returns: all valided configs
+        Returns:
+            all valided configs
 
         """
         assert parser_link is False, f"The parser_link para must be False when parser the _link"
