@@ -21,7 +21,8 @@ logger = Logger('log.txt')
 
 pl.seed_everything(88)
 
-trainer = Train('./norm_lstm_crf/main.hjson')
+# trainer = Train('./norm_lstm_crf/main.hjson')
+trainer = Train('./norm_char_lstm_crf/main.hjson')
 
-print(json.dumps(trainer.configs, indent=3))
-# trainer.run()
+# print(json.dumps(trainer.configs, indent=3))
+trainer.run()
